==> jc-1.4.0.tar.gz: java/awt/geom/Area__24AreaIterator.h <==
// class java.awt.geom.Area$AreaIterator

// class file dependencies
// @dep_class a914e547fa8327bb java_awt_geom_Area__24AreaIterator
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_awt_geom_Area__24AreaIterator_H_
#define _JC_java_awt_geom_Area__24AreaIterator_H_

// Forward structure declarations
struct _jc_java_awt_geom_AffineTransform$object;
struct _jc_java_awt_geom_Area$object;
struct _jc_java_lang_Class$object;
struct _jc_java_util_Vector$object;

// Typedefs
typedef struct _jc_java_awt_geom_Area__24AreaIterator$sub_refs	_jc_java_awt_geom_Area__24AreaIterator$sub_refs;
typedef struct _jc_java_awt_geom_Area__24AreaIterator$sub_nonrefs	_jc_java_awt_geom_Area__24AreaIterator$sub_nonrefs;
typedef struct _jc_java_awt_geom_Area__24AreaIterator$refs	_jc_java_awt_geom_Area__24AreaIterator$refs;
typedef struct _jc_java_awt_geom_Area__24AreaIterator$nonrefs	_jc_java_awt_geom_Area__24AreaIterator$nonrefs;
typedef struct _jc_java_awt_geom_Area__24AreaIterator$object	_jc_java_awt_geom_Area__24AreaIterator$object;

typedef const struct _jc_java_awt_geom_Area__24AreaIterator$vmethods	_jc_java_awt_geom_Area__24AreaIterator$vmethods;
typedef const struct _jc_java_awt_geom_Area__24AreaIterator$vtable	_jc_java_awt_geom_Area__24AreaIterator$vtable;
typedef const struct _jc_java_awt_geom_Area__24AreaIterator$vtype	_jc_java_awt_geom_Area__24AreaIterator$vtype;

// Constructors
extern void _jc_java_awt_geom_Area__24AreaIterator$method$_init$c47127d2d504a20e(_jc_env *, struct _jc_java_awt_geom_Area__24AreaIterator$object *, struct _jc_java_awt_geom_Area$object *, struct _jc_java_awt_geom_AffineTransform$object *);

// Virtual methods
extern jint _jc_java_awt_geom_Area__24AreaIterator$method$currentSegment$6f11896d92c6b52a(_jc_env *, struct _jc_java_awt_geom_Area__24AreaIterator$object *, struct _jc_double_array *);
extern jint _jc_java_awt_geom_Area__24AreaIterator$method$currentSegment$cecac40191e782ca(_jc_env *, struct _jc_java_awt_geom_Area__24AreaIterator$object *, struct _jc_float_array *);
extern jint _jc_java_awt_geom_Area__24AreaIterator$method$getWindingRule$91001ac946a586fb(_jc_env *, struct _jc_java_awt_geom_Area__24AreaIterator$object *);
extern jboolean _jc_java_awt_geom_Area__24AreaIterator$method$isDone$5a7c3805879a074d(_jc_env *, struct _jc_java_awt_geom_Area__24AreaIterator$object *);
extern void _jc_java_awt_geom_Area__24AreaIterator$method$next$08839245f4046cfe(_jc_env *, struct _jc_java_awt_geom_Area__24AreaIterator$object *);

// Virtual method descriptors
extern _jc_method _jc_java_awt_geom_Area__24AreaIterator$method_info$currentSegment$6f11896d92c6b52a;
extern _jc_method _jc_java_awt_geom_Area__24AreaIterator$method_info$currentSegment$cecac40191e782ca;
extern _jc_method _jc_java_awt_geom_Area__24AreaIterator$method_info$getWindingRule$91001ac946a586fb;
extern _jc_method _jc_java_awt_geom_Area__24AreaIterator$method_info$isDone$5a7c3805879a074d;
extern _jc_method _jc_java_awt_geom_Area__24AreaIterator$method_info$next$08839245f4046cfe;

// Virtual methods structure
struct _jc_java_awt_geom_Area__24AreaIterator$vmethods {
	jint	(*currentSegment$6f11896d92c6b52a)(_jc_env *, struct _jc_java_awt_geom_Area__24AreaIterator$object *, struct _jc_double_array *);
	jint	(*currentSegment$cecac40191e782ca)(_jc_env *, struct _jc_java_awt_geom_Area__24AreaIterator$object *, struct _jc_float_array *);
	jint	(*getWindingRule$91001ac946a586fb)(_jc_env *, struct _jc_java_awt_geom_Area__24AreaIterator$object *);
	jboolean	(*isDone$5a7c3805879a074d)(_jc_env *, struct _jc_java_awt_geom_Area__24AreaIterator$object *);
	void	(*next$08839245f4046cfe)(_jc_env *, struct _jc_java_awt_geom_Area__24AreaIterator$object *);
};

// Vtable
struct _jc_java_awt_geom_Area__24AreaIterator$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_geom_Area__24AreaIterator$vmethods	java_awt_geom_Area__24AreaIterator;
};

// Vtype
struct _jc_java_awt_geom_Area__24AreaIterator$vtype {
	_jc_type			type;
	_jc_java_awt_geom_Area__24AreaIterator$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_geom_Area__24AreaIterator$sub_refs {
	struct _jc_java_util_Vector$object	*segments;
	struct _jc_java_awt_geom_AffineTransform$object	*at;
	struct _jc_java_awt_geom_Area$object	*this;
};

// Reference instance fields (object)
struct _jc_java_awt_geom_Area__24AreaIterator$refs {
    _jc_java_awt_geom_Area__24AreaIterator$sub_refs	java_awt_geom_Area__24AreaIterator;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_geom_Area__24AreaIterator$sub_nonrefs {
	jint	index;
};

// Non-reference instance fields (object)
struct _jc_java_awt_geom_Area__24AreaIterator$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_geom_Area__24AreaIterator$sub_nonrefs	java_awt_geom_Area__24AreaIterator;
};

// Object instance structure
struct _jc_java_awt_geom_Area__24AreaIterator$object {
	_jc_java_awt_geom_Area__24AreaIterator$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_geom_Area__24AreaIterator$vtype	*vtype;
	_jc_java_awt_geom_Area__24AreaIterator$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_geom_Area__24AreaIterator$vtype _jc_java_awt_geom_Area__24AreaIterator$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_geom_Area__24AreaIterator, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_geom_Area__24AreaIterator$class_object;

#endif	/* _JC_java_awt_geom_Area__24AreaIterator_H_ */

==> jc-1.4.6.tar.gz: java/awt/geom/Area__24AreaIterator.h <==
// class java.awt.geom.Area$AreaIterator

// class file dependencies
// @dep_class 4923dbfd482d7c9 java_awt_geom_Area__24AreaIterator
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_awt_geom_Area__24AreaIterator_H_
#define _JC_java_awt_geom_Area__24AreaIterator_H_

// Forward structure declarations
struct _jc_java_awt_geom_AffineTransform$object;
struct _jc_java_awt_geom_Area$object;
struct _jc_java_lang_Class$object;
struct _jc_java_util_Vector$object;

// Typedefs
typedef struct _jc_java_awt_geom_Area__24AreaIterator$sub_refs	_jc_java_awt_geom_Area__24AreaIterator$sub_refs;
typedef struct _jc_java_awt_geom_Area__24AreaIterator$sub_nonrefs	_jc_java_awt_geom_Area__24AreaIterator$sub_nonrefs;
typedef struct _jc_java_awt_geom_Area__24AreaIterator$refs	_jc_java_awt_geom_Area__24AreaIterator$refs;
typedef struct _jc_java_awt_geom_Area__24AreaIterator$nonrefs	_jc_java_awt_geom_Area__24AreaIterator$nonrefs;
typedef struct _jc_java_awt_geom_Area__24AreaIterator$object	_jc_java_awt_geom_Area__24AreaIterator$object;

typedef const struct _jc_java_awt_geom_Area__24AreaIterator$vmethods	_jc_java_awt_geom_Area__24AreaIterator$vmethods;
typedef const struct _jc_java_awt_geom_Area__24AreaIterator$vtable	_jc_java_awt_geom_Area__24AreaIterator$vtable;
typedef const struct _jc_java_awt_geom_Area__24AreaIterator$vtype	_jc_java_awt_geom_Area__24AreaIterator$vtype;

// Constructors
extern void _jc_java_awt_geom_Area__24AreaIterator$method$_init$c47127d2d504a20e(_jc_env *, struct _jc_java_awt_geom_Area__24AreaIterator$object *, struct _jc_java_awt_geom_Area$object *, struct _jc_java_awt_geom_AffineTransform$object *) _JC_JCNI_ATTR;

// Virtual methods
extern jint _jc_java_awt_geom_Area__24AreaIterator$method$currentSegment$6f11896d92c6b52a(_jc_env *, struct _jc_java_awt_geom_Area__24AreaIterator$object *, struct _jc_double_array *) _JC_JCNI_ATTR;
extern jint _jc_java_awt_geom_Area__24AreaIterator$method$currentSegment$cecac40191e782ca(_jc_env *, struct _jc_java_awt_geom_Area__24AreaIterator$object *, struct _jc_float_array *) _JC_JCNI_ATTR;
extern jint _jc_java_awt_geom_Area__24AreaIterator$method$getWindingRule$91001ac946a586fb(_jc_env *, struct _jc_java_awt_geom_Area__24AreaIterator$object *) _JC_JCNI_ATTR;
extern jboolean _jc_java_awt_geom_Area__24AreaIterator$method$isDone$5a7c3805879a074d(_jc_env *, struct _jc_java_awt_geom_Area__24AreaIterator$object *) _JC_JCNI_ATTR;
extern void _jc_java_awt_geom_Area__24AreaIterator$method$next$08839245f4046cfe(_jc_env *, struct _jc_java_awt_geom_Area__24AreaIterator$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_awt_geom_Area__24AreaIterator$method_info$currentSegment$6f11896d92c6b52a;
extern _jc_method _jc_java_awt_geom_Area__24AreaIterator$method_info$currentSegment$cecac40191e782ca;
extern _jc_method _jc_java_awt_geom_Area__24AreaIterator$method_info$getWindingRule$91001ac946a586fb;
extern _jc_method _jc_java_awt_geom_Area__24AreaIterator$method_info$isDone$5a7c3805879a074d;
extern _jc_method _jc_java_awt_geom_Area__24AreaIterator$method_info$next$08839245f4046cfe;

// Virtual methods structure
struct _jc_java_awt_geom_Area__24AreaIterator$vmethods {
	jint	(*currentSegment$6f11896d92c6b52a)(_jc_env *, struct _jc_java_awt_geom_Area__24AreaIterator$object *, struct _jc_double_array *) _JC_JCNI_ATTR;
	jint	(*currentSegment$cecac40191e782ca)(_jc_env *, struct _jc_java_awt_geom_Area__24AreaIterator$object *, struct _jc_float_array *) _JC_JCNI_ATTR;
	jint	(*getWindingRule$91001ac946a586fb)(_jc_env *, struct _jc_java_awt_geom_Area__24AreaIterator$object *) _JC_JCNI_ATTR;
	jboolean	(*isDone$5a7c3805879a074d)(_jc_env *, struct _jc_java_awt_geom_Area__24AreaIterator$object *) _JC_JCNI_ATTR;
	void	(*next$08839245f4046cfe)(_jc_env *, struct _jc_java_awt_geom_Area__24AreaIterator$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_awt_geom_Area__24AreaIterator$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_geom_Area__24AreaIterator$vmethods	java_awt_geom_Area__24AreaIterator;
};

// Vtype
struct _jc_java_awt_geom_Area__24AreaIterator$vtype {
	_jc_type			type;
	_jc_java_awt_geom_Area__24AreaIterator$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_geom_Area__24AreaIterator$sub_refs {
	struct _jc_java_util_Vector$object	*segments;
	struct _jc_java_awt_geom_AffineTransform$object	*at;
	struct _jc_java_awt_geom_Area$object	*this;
};

// Reference instance fields (object)
struct _jc_java_awt_geom_Area__24AreaIterator$refs {
    _jc_java_awt_geom_Area__24AreaIterator$sub_refs	java_awt_geom_Area__24AreaIterator;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_geom_Area__24AreaIterator$sub_nonrefs {
	jint	index;
};

// Non-reference instance fields (object)
struct _jc_java_awt_geom_Area__24AreaIterator$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_geom_Area__24AreaIterator$sub_nonrefs	java_awt_geom_Area__24AreaIterator;
};

// Object instance structure
struct _jc_java_awt_geom_Area__24AreaIterator$object {
	_jc_java_awt_geom_Area__24AreaIterator$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_geom_Area__24AreaIterator$vtype	*vtype;
	_jc_java_awt_geom_Area__24AreaIterator$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_geom_Area__24AreaIterator$vtype _jc_java_awt_geom_Area__24AreaIterator$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_geom_Area__24AreaIterator, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_geom_Area__24AreaIterator$class_object;

#endif	/* _JC_java_awt_geom_Area__24AreaIterator_H_ */
